@@ -45,29 +45,30 @@ var NAVTREE =
 var NAVTREEINDEX =
 [
 "aac-types_8h.html",
-"group__pw__core.html#gae40b2a9bf4e42aac082bf90e37389c02",
-"group__pw__impl__node.html#gaa4f5ea619bcdb70245eef636caf8d88e",
-"group__pw__log.html#ga09b2a40e80e5fefd6e7cb84147a73988",
-"group__pw__port.html#gac245481d75b73061398575ed44ab3e07",
-"group__pw__session__manager.html#ga7dcaf114cea354db4a8f610ed968e2a7",
-"group__spa__ansi.html#gaef43ee57bc72517c30237843d256fabc",
-"group__spa__device.html#ga6d0493b863780697cf564ff4ae297191",
-"group__spa__keys.html#gaec49a8bf593696ff1aa0fc19d561d414",
-"group__spa__node.html#ga7d7d4aa2fe72df4d60de993aabb8f70c",
-"group__spa__param.html#ga6e3bce5ed0005d7b42af555d0811bbe1",
-"group__spa__param.html#gga339d759aafadca6ef623f32ce7e65be0abd3b64b083b0d3de5cc398823fd0938e",
-"group__spa__param.html#gga99c6341a3416bdaacc42f77fc4869821ab9e191d2027ed0e2df7c7d4c1c66e7c6",
-"group__spa__param.html#ggad7758d1c91573ef57ebf61ac113bb43ea7aba67e943da602b036a53ec24dae2d6",
-"group__spa__pod.html#ga9cd96f7179e7edcbb4a2385ce48229ad",
-"group__spa__types.html#gga726ca809ffd3d67ab4b8476646f26635a9134670bb87389f183503125e1f9145d",
-"page_man_spa-acp-tool_1.html",
-"structpw__client__endpoint__methods.html#a58fe2e1f1524cf0f22dda84f7f9c33e0",
-"structpw__impl__factory__implementation.html",
-"structpw__protocol__server.html#a0ac79f449a098fd48ac49f48f56a0ed3",
-"structspa__debug__context.html",
-"structspa__loop.html",
-"structspa__ratelimit.html#a45159c1daa14dddd0e911cbbbac0467f"
+"group__pw__core.html#gaab5fd68faa350ca3f2928032b0553a3f",
+"group__pw__impl__module.html#gad0e64478bc2c8627547647a8fd689fe9",
+"group__pw__link.html#ga5d3c859845886244df9d51621460f53b",
+"group__pw__pipewire.html#gaf3d7686492ea5032eb135cddf21d3da2",
+"group__pw__session__manager.html#ga659e95476b1273ad6b2d247256375df7",
+"group__spa__ansi.html#ga5d126113edfe9df70eb7f68a6f874c85",
+"group__spa__debug.html#gad05de600014e815c9aadc8de416cbe06",
+"group__spa__json.html#gab73d06c52e118fb6ff1694e2ca423cb1",
+"group__spa__names.html#gac4ef8bddd1f53a3a890c5ab7bb32db3f",
+"group__spa__param.html#ga33238198e192056d4aba1b75fb7c5828",
+"group__spa__param.html#gae80e1e14b3317a337ea5ac70f6c2c9f4",
+"group__spa__param.html#gga4077adc9cb334bd78d561f96c04eebbcaf3305fb7d954386c02364e9fbb98e5cd",
+"group__spa__param.html#ggacb274daea0abcce261955323e7d0b1aaa2cc5175abd3f6648bb173a3637744b2b",
+"group__spa__pod.html#ga2fb7171ab4bf8b85b835c8ac66cc3a26",
+"group__spa__string.html#ga09d9f308bcb98d09e25655e8446df5ce",
+"impl-device_8h.html",
+"page_pulseaudio.html",
+"structpw__device__info.html#accce9f7bcbbb1e5142298f18ce03d799",
+"structpw__memchunk.html",
+"structspa__audio__aec__methods.html#af7b0dbc68aecaab0c278bc95a9d37503",
+"structspa__graph__node.html#af4ae9586aa3d544a48414987f1839a67",
+"structspa__node__info.html#a41964dbf3b7ace8dd61b9f82d123b4d6",
+"structspa__type__info.html#afedc2465e18bf4d93bf2a3d8afcc4c13"
 ];
 
-var SYNCONMSG = 'click to disable panel synchronisation';
-var SYNCOFFMSG = 'click to enable panel synchronisation';
\ No newline at end of file
+var SYNCONMSG = 'click to disable panel synchronization';
+var SYNCOFFMSG = 'click to enable panel synchronization';
\ No newline at end of file
